pub enum PollResult {
None,
Reset,
Data {
ep_out: u16,
ep_in_complete: u16,
ep_setup: u16,
},
Suspend,
Resume,
}Event and incoming packet information returned by UsbBus::poll.
No events or packets to report.
The USB reset condition has been detected.
USB packets have been received or sent. Each data field is a bit-field where the least
significant bit represents endpoint 0 etc., and a set bit signifies the event has occurred
for the corresponding endpoint.
Fields of Data
An OUT packet has been received. This event should continue to be reported until the
packet is read.
An IN packet has finished transmitting. This event should only be reported once for each
completed transfer.
A SETUP packet has been received. The corresponding bit in ep_out may also be set but
is ignored.
A USB suspend request has been detected or, in the case of self-powered devices, the device
has been disconnected from the USB usb.
A USB resume request has been detected after being suspended or, in the case of self-powered
devices, the device has been connected to the USB usb.
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static