pub struct ControlIn<'a, 'p, 'r, B: UsbBus> { /* private fields */ }Expand description
Handle for a control IN transfer. When implementing a class, use the methods of this object to response to the transfer with either data or an error (STALL condition). To ignore the request and pass it on to the next class, simply don’t call any method.
Implementations
Sourceimpl<'a, 'p, 'r, B: UsbBus> ControlIn<'a, 'p, 'r, B>
impl<'a, 'p, 'r, B: UsbBus> ControlIn<'a, 'p, 'r, B>
Sourcepub fn accept_with(self, data: &[u8]) -> Result<()>
pub fn accept_with(self, data: &[u8]) -> Result<()>
Accepts the transfer with the supplied buffer.
Sourcepub fn accept_with_static(self, data: &'static [u8]) -> Result<()>
pub fn accept_with_static(self, data: &'static [u8]) -> Result<()>
Accepts the transfer with the supplied static buffer. This method is useful when you have a large static descriptor to send as one packet.