pub struct ControlOut<'a, 'p, 'r, B: UsbBus> { /* private fields */ }Expand description
Handle for a control OUT transfer. When implementing a class, use the methods of this object to response to the transfer with an ACT or an error (STALL condition). To ignore the request and pass it on to the next class, simply don’t call any method.
Implementations