UsbDeviceState

Enum UsbDeviceState 

#[repr(u8)]
pub enum UsbDeviceState { Default = 0, Addressed = 1, Configured = 2, Suspend = 3, }
The global state of the USB device.

In general class traffic is only possible in the Configured state.

Variants



Default = 0

The USB device has just been created or reset.



Addressed = 1

The USB device has received an address from the host.



Configured = 2

The USB device has been configured and is fully functional.



Suspend = 3

The USB device has been suspended by the host or it has been unplugged from the USB bus.