EndpointType

Enum EndpointType 

pub enum EndpointType {
    Control,
    Isochronous {
        synchronization: IsochronousSynchronizationType,
        usage: IsochronousUsageType,
    },
    Bulk,
    Interrupt,
}
USB endpoint transfer type.

Variants



Control

Control endpoint. Used for device management. Only the host can initiate requests. Usually used only endpoint 0.



Isochronous

Isochronous endpoint. Used for time-critical unreliable data.

See USB 2.0 spec section 5.12 “Special Considerations for Isochronous Transfers”

Fields

synchronization: IsochronousSynchronizationType

Synchronization model used for the data stream that this endpoint relates to.

usage: IsochronousUsageType

Endpoint’s role in the synchronization model selected by Self::Isochronous::synchronization.



Bulk

Bulk endpoint. Used for large amounts of best-effort reliable data.



Interrupt

Interrupt endpoint. Used for small amounts of time-critical reliable data.

Implementations

Source

impl EndpointType

pub fn to_bm_attributes(&self) -> u8

Format EndpointType for use in bmAttributes transfer type field USB 2.0 spec section 9.6.6